@@ -1189,6 +1189,38 @@ class AdWordsClient(Client):
     return GenericAdWordsService(headers, self._config, op_config, self.__lock,
                                  self.__logger, 'GeoLocationService')
 
+  def GetLabelService(self, server='https://adwords.google.com',
+                            version=None, http_proxy=None):
+    """Call API method in LabelService.
+
+    Args:
+      [optional]
+      server: str API server to access for this API call. The only supported
+              server is currently 'https://adwords.google.com'.
+      version: str API version to use.
+      http_proxy: str HTTP proxy to use.
+
+    Returns:
+      GenericAdWordsService New instance of LabelService object.
+    """
+    headers = self.__GetAuthCredentialsForAccessLevel()
+
+    if version is None:
+      version = DEFAULT_API_VERSION
+    if Utils.BoolTypeConvert(self._config['strict']):
+      AdWordsSanityCheck.ValidateServer(server, version)
+
+    # Load additional configuration data.
+    op_config = {
+        'server': server,
+        'version': version,
+        'group': 'cm',
+        'default_group': 'cm',
+        'http_proxy': http_proxy
+    }
+    return GenericAdWordsService(headers, self._config, op_config, self.__lock,
+                                 self.__logger, 'LabelService')
+
   def GetLocationCriterionService(self, server='https://adwords.google.com',
                                   version=None, http_proxy=None):
     """Call API method in LocationCriterionService.
